@@ -1,5 +1,29 @@
 # -*- coding: utf-8 -*-
 #
+"""
+
+"""
+
+"""
+websocket - WebSocket client library for Python
+
+Copyright (C) 2010 Hiroki Ohtani(liris)
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+
+"""
 
 import sys
 sys.path[0:0] = [""]
@@ -55,6 +79,9 @@ class SockMock(object):
     def add_packet(self, data):
         self.data.append(data)
 
+    def gettimeout(self):
+        return None
+
     def recv(self, bufsize):
         if self.data:
             e = self.data.pop(0)
@@ -219,6 +246,8 @@ class WebSocketTest(unittest.TestCase):
         header["sec-websocket-protocol"] = "sUb1"
         self.assertEqual(_validate_header(header, key, ["Sub1", "suB2"]), (True, "sub1"))
 
+        header = required_header.copy()
+        self.assertEqual(_validate_header(header, key, ["Sub1", "suB2"]), (False, None))
 
     def testReadHeader(self):
         status, header, status_message = read_headers(HeaderSockMock("data/header01.txt"))
@@ -260,14 +289,14 @@ class WebSocketTest(unittest.TestCase):
     @unittest.skipUnless(TEST_WITH_INTERNET, "Internet-requiring tests are disabled")
     def testIter(self):
         count = 2
-        for _ in ws.create_connection('ws://stream.meetup.com/2/rsvps'):
+        for _ in ws.create_connection('wss://stream.meetup.com/2/rsvps'):
             count -= 1
             if count == 0:
                 break
 
     @unittest.skipUnless(TEST_WITH_INTERNET, "Internet-requiring tests are disabled")
     def testNext(self):
-        sock = ws.create_connection('ws://stream.meetup.com/2/rsvps')
+        sock = ws.create_connection('wss://stream.meetup.com/2/rsvps')
         self.assertEqual(str, type(next(sock)))
 
     def testInternalRecvStrict(self):
@@ -444,7 +473,7 @@ class WebSocketTest(unittest.TestCase):
         #    pass
 
     @unittest.skipUnless(TEST_WITH_INTERNET, "Internet-requiring tests are disabled")
-    def testWebSocketWihtCustomHeader(self):
+    def testWebSocketWithCustomHeader(self):
         s = ws.create_connection("ws://echo.websocket.org/",
                                  headers={"User-Agent": "PythonWebsocketClient"})
         self.assertNotEqual(s, None)
@@ -542,28 +571,6 @@ class WebSocketAppTest(unittest.TestCase):
         # Note: We can't use 'is' for comparing the functions directly, need to use 'id'.
         # self.assertEqual(WebSocketAppTest.get_mask_key_id, id(my_mask_key_func))
 
-    def testSettingClassCallbacks(self):
-        """ App class should provide possibility to set callback functions via class instantiate call, class inheritance
-        and via setting instance attributes
-        """
-        class TestApp(ws.WebSocketApp):
-            def on_close(self):
-                pass
-
-        def on_open(ws):
-            pass
-
-        def on_message(ws):
-            pass
-
-        app = TestApp('ws://www.example.com/', on_open=on_open)
-        app.on_message = on_message
-
-        #assert isinstance(app.on_close, function)
-        assert callable(app.on_open)
-        assert callable(app.on_message)
-        assert callable(app.on_close)
-
 
 class SockOptTest(unittest.TestCase):
     @unittest.skipUnless(TEST_WITH_INTERNET, "Internet-requiring tests are disabled")
